# coding: utf-8

"""
    ARLAS CITY API

    Upload GTFS data

    OpenAPI spec version: 0.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import arlas_city_api_python
from arlas_city_api_python.rest import ApiException
from arlas_city_api_python.apis.write_api import WriteApi


class TestWriteApi(unittest.TestCase):
    """ WriteApi unit test stubs """

    def setUp(self):
        self.api = arlas_city_api_python.apis.write_api.WriteApi()

    def tearDown(self):
        pass

    def test_upload(self):
        """
        Test case for upload

        Upload a GTFS archive.
        """
        pass


if __name__ == '__main__':
    unittest.main()
