# coding: utf-8

"""
    ARLAS City API

    Upload GTFS data

    OpenAPI spec version: 5.0.0
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import sys
from setuptools import setup, find_packages

NAME = "arlas-city_api"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="ARLAS Exploration API",
    author = "Gisaïa",
    author_email="contact@gisaia.com",
    url="https://github.com/gisaia/ARLAS-server",
    keywords=["Arlas", "ARLAS Exploration API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Explore the content of ARLAS collections
    """
)
